@@ -12,7 +12,7 @@ else:
 import async_timeout
 import redis.asyncio as redis_async  # aioredis was integrated into redis in version 4.2.0 as redis.asyncio
 
-from . import _fakesocket
+from . import _fakesocket, FakeServer
 from . import _helpers
 from . import _msgs as msgs
 from . import _server
@@ -100,7 +100,9 @@ class FakeWriter:
 
 class FakeConnection(redis_async.Connection):
     def __init__(self, *args, **kwargs):
-        self._server = kwargs.pop('server')
+        self._server = kwargs.pop('server', None)
+        if self._server is None:
+            self._server = FakeServer()
         self._sock = None
         super().__init__(*args, **kwargs)
 
@@ -111,8 +113,8 @@ class FakeConnection(redis_async.Connection):
         self._reader = FakeReader(self._sock)
         self._writer = FakeWriter(self._sock)
 
-    async def disconnect(self):
-        await super().disconnect()
+    async def disconnect(self, **kwargs):
+        await super().disconnect(**kwargs)
         self._sock = None
 
     async def can_read(self, timeout: float = 0):
@@ -148,7 +150,9 @@ class FakeConnection(redis_async.Connection):
             except asyncio.QueueEmpty:
                 raise redis_async.ConnectionError(msgs.CONNECTION_ERROR_MSG)
         else:
-            response = await self._sock.responses.get()
+            timeout = kwargs.pop('timeout', None)
+            can_read = await self.can_read(timeout)
+            response = await self._reader.read(0) if can_read else None
         if isinstance(response, redis_async.ResponseError):
             raise response
         return self._decode(response)
